# coding: utf-8

"""
    Kloudio APIs

"""


from __future__ import absolute_import

import unittest
import datetime

import kloudio
from kloudio.models.connection_respose import ConnectionRespose  # noqa: E501
from kloudio.rest import ApiException

class TestConnectionRespose(unittest.TestCase):
    """ConnectionRespose unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ConnectionRespose
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = kloudio.models.connection_respose.ConnectionRespose()  # noqa: E501
        if include_optional :
            return ConnectionRespose(
                id = '0', 
                name = '0', 
                host = '0', 
                port = '0', 
                database = '0', 
                username = '0', 
                password = '0', 
                db_type = '0', 
                production = True, 
                user = 1.337, 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                ssl = True, 
                updated_by = '0', 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                shared_with = None, 
                enable_tunnel = True, 
                tunnel_info = None, 
                other_options = None, 
                fed = True, 
                dw = True, 
                metadata = '0', 
                connection_type = '0', 
                integration_user_id = 1.337, 
                web_type = '0', 
                ssl_info = None
            )
        else :
            return ConnectionRespose(
                id = '0',
                name = '0',
                host = '0',
                port = '0',
                database = '0',
        )

    def testConnectionRespose(self):
        """Test ConnectionRespose"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kloudio APIs

"""


from __future__ import absolute_import

import unittest

import kloudio
from kloudio.api.jobs_api import JobsApi  # noqa: E501
from kloudio.rest import ApiException


class TestJobsApi(unittest.TestCase):
    """JobsApi unit test stubs"""

    def setUp(self):
        self.api = kloudio.api.jobs_api.JobsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_job(self):
        """Test case for create_job

        Create a job  # noqa: E501
        """
        pass

    def test_delete_job(self):
        """Test case for delete_job

        Delete a job  # noqa: E501
        """
        pass

    def test_disable_job(self):
        """Test case for disable_job

        Disable a job  # noqa: E501
        """
        pass

    def test_enable_job(self):
        """Test case for enable_job

        Enable a job  # noqa: E501
        """
        pass

    def test_resume_jobs(self):
        """Test case for resume_jobs

        Resume jobs  # noqa: E501
        """
        pass

    def test_retrieve_job(self):
        """Test case for retrieve_job

        Get a job  # noqa: E501
        """
        pass

    def test_retrieve_jobs(self):
        """Test case for retrieve_jobs

        Get all jobs  # noqa: E501
        """
        pass

    def test_run_job(self):
        """Test case for run_job

        Run a job  # noqa: E501
        """
        pass

    def test_suspend_jobs(self):
        """Test case for suspend_jobs

        Suspend jobs  # noqa: E501
        """
        pass

    def test_update_job(self):
        """Test case for update_job

        Update a job  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kloudio APIs

"""


import pprint
import re  # noqa: F401

import six

from kloudio.configuration import Configuration


class NewJob(object):
    """
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'destination': 'str',
        'report_name': 'str',
        'report_id': 'str',
        'report_params': 'object',
        'frequency': 'str',
        'am_pm': 'str',
        'hour': 'str',
        'minute': 'str',
        'day': 'str',
        'description': 'str',
        'spreadsheet_id': 'str',
        'sheet_id': 'str',
        'sheet_name': 'str',
        'timezone': 'str',
        'select_cols': 'object',
        'tags': 'str',
        'email_on_success': 'bool',
        'email_on_error': 'bool',
        'metadata': 'object',
        'template_id': 'str',
        'template_name': 'str',
        'job_type': 'str'
    }

    attribute_map = {
        'destination': 'destination',
        'report_name': 'report_name',
        'report_id': 'report_id',
        'report_params': 'report_params',
        'frequency': 'frequency',
        'am_pm': 'amPm',
        'hour': 'hour',
        'minute': 'minute',
        'day': 'day',
        'description': 'description',
        'spreadsheet_id': 'spreadsheet_id',
        'sheet_id': 'sheetId',
        'sheet_name': 'sheetName',
        'timezone': 'timezone',
        'select_cols': 'select_cols',
        'tags': 'tags',
        'email_on_success': 'email_on_success',
        'email_on_error': 'email_on_error',
        'metadata': 'metadata',
        'template_id': 'templateId',
        'template_name': 'templateName',
        'job_type': 'jobType'
    }

    def __init__(self, destination=None, report_name=None, report_id=None, report_params=None, frequency=None, am_pm=None, hour=None, minute=None, day=None, description=None, spreadsheet_id=None, sheet_id=None, sheet_name=None, timezone=None, select_cols=None, tags=None, email_on_success=None, email_on_error=None, metadata=None, template_id=None, template_name=None, job_type=None, local_vars_configuration=None):  # noqa: E501
        """NewJob - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._destination = None
        self._report_name = None
        self._report_id = None
        self._report_params = None
        self._frequency = None
        self._am_pm = None
        self._hour = None
        self._minute = None
        self._day = None
        self._description = None
        self._spreadsheet_id = None
        self._sheet_id = None
        self._sheet_name = None
        self._timezone = None
        self._select_cols = None
        self._tags = None
        self._email_on_success = None
        self._email_on_error = None
        self._metadata = None
        self._template_id = None
        self._template_name = None
        self._job_type = None
        self.discriminator = None

        self.destination = destination
        self.report_name = report_name
        self.report_id = report_id
        if report_params is not None:
            self.report_params = report_params
        self.frequency = frequency
        self.am_pm = am_pm
        self.hour = hour
        self.minute = minute
        self.day = day
        if description is not None:
            self.description = description
        if spreadsheet_id is not None:
            self.spreadsheet_id = spreadsheet_id
        if sheet_id is not None:
            self.sheet_id = sheet_id
        if sheet_name is not None:
            self.sheet_name = sheet_name
        if timezone is not None:
            self.timezone = timezone
        if select_cols is not None:
            self.select_cols = select_cols
        if tags is not None:
            self.tags = tags
        if email_on_success is not None:
            self.email_on_success = email_on_success
        if email_on_error is not None:
            self.email_on_error = email_on_error
        if metadata is not None:
            self.metadata = metadata
        if template_id is not None:
            self.template_id = template_id
        if template_name is not None:
            self.template_name = template_name
        if job_type is not None:
            self.job_type = job_type

    @property
    def destination(self):
        """Gets the destination of this NewJob.  # noqa: E501


        :return: The destination of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._destination

    @destination.setter
    def destination(self, destination):
        """Sets the destination of this NewJob.


        :param destination: The destination of this NewJob.  # noqa: E501
        :type destination: str
        """
        if self.local_vars_configuration.client_side_validation and destination is None:  # noqa: E501
            raise ValueError("Invalid value for `destination`, must not be `None`")  # noqa: E501

        self._destination = destination

    @property
    def report_name(self):
        """Gets the report_name of this NewJob.  # noqa: E501


        :return: The report_name of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._report_name

    @report_name.setter
    def report_name(self, report_name):
        """Sets the report_name of this NewJob.


        :param report_name: The report_name of this NewJob.  # noqa: E501
        :type report_name: str
        """
        if self.local_vars_configuration.client_side_validation and report_name is None:  # noqa: E501
            raise ValueError("Invalid value for `report_name`, must not be `None`")  # noqa: E501

        self._report_name = report_name

    @property
    def report_id(self):
        """Gets the report_id of this NewJob.  # noqa: E501


        :return: The report_id of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._report_id

    @report_id.setter
    def report_id(self, report_id):
        """Sets the report_id of this NewJob.


        :param report_id: The report_id of this NewJob.  # noqa: E501
        :type report_id: str
        """
        if self.local_vars_configuration.client_side_validation and report_id is None:  # noqa: E501
            raise ValueError("Invalid value for `report_id`, must not be `None`")  # noqa: E501

        self._report_id = report_id

    @property
    def report_params(self):
        """Gets the report_params of this NewJob.  # noqa: E501


        :return: The report_params of this NewJob.  # noqa: E501
        :rtype: object
        """
        return self._report_params

    @report_params.setter
    def report_params(self, report_params):
        """Sets the report_params of this NewJob.


        :param report_params: The report_params of this NewJob.  # noqa: E501
        :type report_params: object
        """

        self._report_params = report_params

    @property
    def frequency(self):
        """Gets the frequency of this NewJob.  # noqa: E501


        :return: The frequency of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._frequency

    @frequency.setter
    def frequency(self, frequency):
        """Sets the frequency of this NewJob.


        :param frequency: The frequency of this NewJob.  # noqa: E501
        :type frequency: str
        """
        if self.local_vars_configuration.client_side_validation and frequency is None:  # noqa: E501
            raise ValueError("Invalid value for `frequency`, must not be `None`")  # noqa: E501

        self._frequency = frequency

    @property
    def am_pm(self):
        """Gets the am_pm of this NewJob.  # noqa: E501


        :return: The am_pm of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._am_pm

    @am_pm.setter
    def am_pm(self, am_pm):
        """Sets the am_pm of this NewJob.


        :param am_pm: The am_pm of this NewJob.  # noqa: E501
        :type am_pm: str
        """
        if self.local_vars_configuration.client_side_validation and am_pm is None:  # noqa: E501
            raise ValueError("Invalid value for `am_pm`, must not be `None`")  # noqa: E501

        self._am_pm = am_pm

    @property
    def hour(self):
        """Gets the hour of this NewJob.  # noqa: E501


        :return: The hour of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._hour

    @hour.setter
    def hour(self, hour):
        """Sets the hour of this NewJob.


        :param hour: The hour of this NewJob.  # noqa: E501
        :type hour: str
        """
        if self.local_vars_configuration.client_side_validation and hour is None:  # noqa: E501
            raise ValueError("Invalid value for `hour`, must not be `None`")  # noqa: E501

        self._hour = hour

    @property
    def minute(self):
        """Gets the minute of this NewJob.  # noqa: E501


        :return: The minute of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._minute

    @minute.setter
    def minute(self, minute):
        """Sets the minute of this NewJob.


        :param minute: The minute of this NewJob.  # noqa: E501
        :type minute: str
        """
        if self.local_vars_configuration.client_side_validation and minute is None:  # noqa: E501
            raise ValueError("Invalid value for `minute`, must not be `None`")  # noqa: E501

        self._minute = minute

    @property
    def day(self):
        """Gets the day of this NewJob.  # noqa: E501


        :return: The day of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._day

    @day.setter
    def day(self, day):
        """Sets the day of this NewJob.


        :param day: The day of this NewJob.  # noqa: E501
        :type day: str
        """
        if self.local_vars_configuration.client_side_validation and day is None:  # noqa: E501
            raise ValueError("Invalid value for `day`, must not be `None`")  # noqa: E501

        self._day = day

    @property
    def description(self):
        """Gets the description of this NewJob.  # noqa: E501


        :return: The description of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this NewJob.


        :param description: The description of this NewJob.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def spreadsheet_id(self):
        """Gets the spreadsheet_id of this NewJob.  # noqa: E501


        :return: The spreadsheet_id of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._spreadsheet_id

    @spreadsheet_id.setter
    def spreadsheet_id(self, spreadsheet_id):
        """Sets the spreadsheet_id of this NewJob.


        :param spreadsheet_id: The spreadsheet_id of this NewJob.  # noqa: E501
        :type spreadsheet_id: str
        """

        self._spreadsheet_id = spreadsheet_id

    @property
    def sheet_id(self):
        """Gets the sheet_id of this NewJob.  # noqa: E501


        :return: The sheet_id of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._sheet_id

    @sheet_id.setter
    def sheet_id(self, sheet_id):
        """Sets the sheet_id of this NewJob.


        :param sheet_id: The sheet_id of this NewJob.  # noqa: E501
        :type sheet_id: str
        """

        self._sheet_id = sheet_id

    @property
    def sheet_name(self):
        """Gets the sheet_name of this NewJob.  # noqa: E501


        :return: The sheet_name of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._sheet_name

    @sheet_name.setter
    def sheet_name(self, sheet_name):
        """Sets the sheet_name of this NewJob.


        :param sheet_name: The sheet_name of this NewJob.  # noqa: E501
        :type sheet_name: str
        """

        self._sheet_name = sheet_name

    @property
    def timezone(self):
        """Gets the timezone of this NewJob.  # noqa: E501


        :return: The timezone of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """Sets the timezone of this NewJob.


        :param timezone: The timezone of this NewJob.  # noqa: E501
        :type timezone: str
        """

        self._timezone = timezone

    @property
    def select_cols(self):
        """Gets the select_cols of this NewJob.  # noqa: E501


        :return: The select_cols of this NewJob.  # noqa: E501
        :rtype: object
        """
        return self._select_cols

    @select_cols.setter
    def select_cols(self, select_cols):
        """Sets the select_cols of this NewJob.


        :param select_cols: The select_cols of this NewJob.  # noqa: E501
        :type select_cols: object
        """

        self._select_cols = select_cols

    @property
    def tags(self):
        """Gets the tags of this NewJob.  # noqa: E501


        :return: The tags of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this NewJob.


        :param tags: The tags of this NewJob.  # noqa: E501
        :type tags: str
        """

        self._tags = tags

    @property
    def email_on_success(self):
        """Gets the email_on_success of this NewJob.  # noqa: E501


        :return: The email_on_success of this NewJob.  # noqa: E501
        :rtype: bool
        """
        return self._email_on_success

    @email_on_success.setter
    def email_on_success(self, email_on_success):
        """Sets the email_on_success of this NewJob.


        :param email_on_success: The email_on_success of this NewJob.  # noqa: E501
        :type email_on_success: bool
        """

        self._email_on_success = email_on_success

    @property
    def email_on_error(self):
        """Gets the email_on_error of this NewJob.  # noqa: E501


        :return: The email_on_error of this NewJob.  # noqa: E501
        :rtype: bool
        """
        return self._email_on_error

    @email_on_error.setter
    def email_on_error(self, email_on_error):
        """Sets the email_on_error of this NewJob.


        :param email_on_error: The email_on_error of this NewJob.  # noqa: E501
        :type email_on_error: bool
        """

        self._email_on_error = email_on_error

    @property
    def metadata(self):
        """Gets the metadata of this NewJob.  # noqa: E501


        :return: The metadata of this NewJob.  # noqa: E501
        :rtype: object
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this NewJob.


        :param metadata: The metadata of this NewJob.  # noqa: E501
        :type metadata: object
        """

        self._metadata = metadata

    @property
    def template_id(self):
        """Gets the template_id of this NewJob.  # noqa: E501


        :return: The template_id of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._template_id

    @template_id.setter
    def template_id(self, template_id):
        """Sets the template_id of this NewJob.


        :param template_id: The template_id of this NewJob.  # noqa: E501
        :type template_id: str
        """

        self._template_id = template_id

    @property
    def template_name(self):
        """Gets the template_name of this NewJob.  # noqa: E501


        :return: The template_name of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._template_name

    @template_name.setter
    def template_name(self, template_name):
        """Sets the template_name of this NewJob.


        :param template_name: The template_name of this NewJob.  # noqa: E501
        :type template_name: str
        """

        self._template_name = template_name

    @property
    def job_type(self):
        """Gets the job_type of this NewJob.  # noqa: E501


        :return: The job_type of this NewJob.  # noqa: E501
        :rtype: str
        """
        return self._job_type

    @job_type.setter
    def job_type(self, job_type):
        """Sets the job_type of this NewJob.


        :param job_type: The job_type of this NewJob.  # noqa: E501
        :type job_type: str
        """

        self._job_type = job_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NewJob):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NewJob):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kloudio APIs

"""


from __future__ import absolute_import

import unittest

import kloudio
from kloudio.api.register_api import RegisterApi  # noqa: E501
from kloudio.rest import ApiException


class TestRegisterApi(unittest.TestCase):
    """RegisterApi unit test stubs"""

    def setUp(self):
        self.api = kloudio.api.register_api.RegisterApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_register_user(self):
        """Test case for register_user

        Register a user  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Kloudio APIs

"""


from __future__ import absolute_import

# import models into model package
from kloudio.models.connection_del_response import ConnectionDelResponse
from kloudio.models.connection_respose import ConnectionRespose
from kloudio.models.connection_share_response import ConnectionShareResponse
from kloudio.models.error_response import ErrorResponse
from kloudio.models.jobs_array import JobsArray
from kloudio.models.new_connection import NewConnection
from kloudio.models.new_job import NewJob
from kloudio.models.new_license import NewLicense
from kloudio.models.new_report import NewReport
from kloudio.models.new_user import NewUser
from kloudio.models.report_del_response import ReportDelResponse
from kloudio.models.report_share_response import ReportShareResponse
from kloudio.models.reports_response import ReportsResponse
from kloudio.models.run_report import RunReport
from kloudio.models.share_connection import ShareConnection
from kloudio.models.share_report import ShareReport
from kloudio.models.update_connection import UpdateConnection
from kloudio.models.update_license import UpdateLicense



# coding: utf-8

"""
    Kloudio APIs

"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from kloudio.api_client import ApiClient
from kloudio.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ConnectionsApi(object):
    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def clone_connection(self, connection_id, **kwargs):  # noqa: E501
        """Clone a connection  # noqa: E501

        Use this method to clone an existing connection  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.clone_connection(connection_id, async_req=True)
        >>> result = thread.get()

        :param connection_id: (required)
        :type connection_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ConnectionRespose
        """
        kwargs['_return_http_data_only'] = True
        return self.clone_connection_with_http_info(connection_id, **kwargs)  # noqa: E501

    def clone_connection_with_http_info(self, connection_id, **kwargs):  # noqa: E501
        """Clone a connection  # noqa: E501

        Use this method to clone an existing connection  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.clone_connection_with_http_info(connection_id, async_req=True)
        >>> result = thread.get()

        :param connection_id: (required)
        :type connection_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ConnectionRespose, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'connection_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method clone_connection" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'connection_id' is set
        if self.api_client.client_side_validation and ('connection_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['connection_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `connection_id` when calling `clone_connection`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'connection_id' in local_var_params:
            path_params['connection_id'] = local_var_params['connection_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/connections/{connection_id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConnectionRespose',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def create_connection(self, new_connection, **kwargs):  # noqa: E501
        """Create a connection  # noqa: E501

        Use this method to create a new connection. On successful creation, it returns the connection object  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_connection(new_connection, async_req=True)
        >>> result = thread.get()

        :param new_connection: To create a new connection, send the following properties (required)
        :type new_connection: NewConnection
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ConnectionRespose
        """
        kwargs['_return_http_data_only'] = True
        return self.create_connection_with_http_info(new_connection, **kwargs)  # noqa: E501

    def create_connection_with_http_info(self, new_connection, **kwargs):  # noqa: E501
        """Create a connection  # noqa: E501

        Use this method to create a new connection. On successful creation, it returns the connection object  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_connection_with_http_info(new_connection, async_req=True)
        >>> result = thread.get()

        :param new_connection: To create a new connection, send the following properties (required)
        :type new_connection: NewConnection
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ConnectionRespose, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'new_connection'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_connection" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'new_connection' is set
        if self.api_client.client_side_validation and ('new_connection' not in local_var_params or  # noqa: E501
                                                        local_var_params['new_connection'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `new_connection` when calling `create_connection`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'new_connection' in local_var_params:
            body_params = local_var_params['new_connection']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/connections', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConnectionRespose',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def delete_connection(self, connection_id, **kwargs):  # noqa: E501
        """Delete a connection  # noqa: E501

        Use this method to delete a connection by the ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_connection(connection_id, async_req=True)
        >>> result = thread.get()

        :param connection_id: (required)
        :type connection_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ConnectionDelResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_connection_with_http_info(connection_id, **kwargs)  # noqa: E501

    def delete_connection_with_http_info(self, connection_id, **kwargs):  # noqa: E501
        """Delete a connection  # noqa: E501

        Use this method to delete a connection by the ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_connection_with_http_info(connection_id, async_req=True)
        >>> result = thread.get()

        :param connection_id: (required)
        :type connection_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ConnectionDelResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'connection_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_connection" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'connection_id' is set
        if self.api_client.client_side_validation and ('connection_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['connection_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `connection_id` when calling `delete_connection`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'connection_id' in local_var_params:
            path_params['connection_id'] = local_var_params['connection_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/connections/{connection_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConnectionDelResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def retrieve_connection(self, connection_id, **kwargs):  # noqa: E501
        """Get a connection  # noqa: E501

        Use this method to get a connection by the ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.retrieve_connection(connection_id, async_req=True)
        >>> result = thread.get()

        :param connection_id: (required)
        :type connection_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ConnectionRespose
        """
        kwargs['_return_http_data_only'] = True
        return self.retrieve_connection_with_http_info(connection_id, **kwargs)  # noqa: E501

    def retrieve_connection_with_http_info(self, connection_id, **kwargs):  # noqa: E501
        """Get a connection  # noqa: E501

        Use this method to get a connection by the ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.retrieve_connection_with_http_info(connection_id, async_req=True)
        >>> result = thread.get()

        :param connection_id: (required)
        :type connection_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ConnectionRespose, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'connection_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_connection" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'connection_id' is set
        if self.api_client.client_side_validation and ('connection_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['connection_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `connection_id` when calling `retrieve_connection`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'connection_id' in local_var_params:
            path_params['connection_id'] = local_var_params['connection_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/connections/{connection_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConnectionRespose',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def retrieve_connections(self, **kwargs):  # noqa: E501
        """Get all connections  # noqa: E501

        Use this method to get all connections you have created and have been shared with you.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.retrieve_connections(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: list[ConnectionRespose]
        """
        kwargs['_return_http_data_only'] = True
        return self.retrieve_connections_with_http_info(**kwargs)  # noqa: E501

    def retrieve_connections_with_http_info(self, **kwargs):  # noqa: E501
        """Get all connections  # noqa: E501

        Use this method to get all connections you have created and have been shared with you.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.retrieve_connections_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(list[ConnectionRespose], status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_connections" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/connections', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ConnectionRespose]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def share_connection(self, connection_id, share_connection, **kwargs):  # noqa: E501
        """Share a connection  # noqa: E501

        Use this method to share an existing connection with other members  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.share_connection(connection_id, share_connection, async_req=True)
        >>> result = thread.get()

        :param connection_id: (required)
        :type connection_id: str
        :param share_connection: (required)
        :type share_connection: list[ShareConnection]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ConnectionShareResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.share_connection_with_http_info(connection_id, share_connection, **kwargs)  # noqa: E501

    def share_connection_with_http_info(self, connection_id, share_connection, **kwargs):  # noqa: E501
        """Share a connection  # noqa: E501

        Use this method to share an existing connection with other members  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.share_connection_with_http_info(connection_id, share_connection, async_req=True)
        >>> result = thread.get()

        :param connection_id: (required)
        :type connection_id: str
        :param share_connection: (required)
        :type share_connection: list[ShareConnection]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ConnectionShareResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'connection_id',
            'share_connection'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method share_connection" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'connection_id' is set
        if self.api_client.client_side_validation and ('connection_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['connection_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `connection_id` when calling `share_connection`")  # noqa: E501
        # verify the required parameter 'share_connection' is set
        if self.api_client.client_side_validation and ('share_connection' not in local_var_params or  # noqa: E501
                                                        local_var_params['share_connection'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `share_connection` when calling `share_connection`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'connection_id' in local_var_params:
            path_params['connection_id'] = local_var_params['connection_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'share_connection' in local_var_params:
            body_params = local_var_params['share_connection']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/connections/share/{connection_id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConnectionShareResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))

    def update_connection(self, connection_id, update_connection, **kwargs):  # noqa: E501
        """Update a connection  # noqa: E501

        Use this method to update a new connection. To update a connection, pass in the connection_id as a parameter and the properties you wish to change in the body.On successful creation, it returns the updated connection object  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_connection(connection_id, update_connection, async_req=True)
        >>> result = thread.get()

        :param connection_id: (required)
        :type connection_id: str
        :param update_connection: Pass in the properties you wish to change as an object in the body of the request (required)
        :type update_connection: UpdateConnection
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ConnectionRespose
        """
        kwargs['_return_http_data_only'] = True
        return self.update_connection_with_http_info(connection_id, update_connection, **kwargs)  # noqa: E501

    def update_connection_with_http_info(self, connection_id, update_connection, **kwargs):  # noqa: E501
        """Update a connection  # noqa: E501

        Use this method to update a new connection. To update a connection, pass in the connection_id as a parameter and the properties you wish to change in the body.On successful creation, it returns the updated connection object  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_connection_with_http_info(connection_id, update_connection, async_req=True)
        >>> result = thread.get()

        :param connection_id: (required)
        :type connection_id: str
        :param update_connection: Pass in the properties you wish to change as an object in the body of the request (required)
        :type update_connection: UpdateConnection
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ConnectionRespose, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'connection_id',
            'update_connection'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_connection" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'connection_id' is set
        if self.api_client.client_side_validation and ('connection_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['connection_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `connection_id` when calling `update_connection`")  # noqa: E501
        # verify the required parameter 'update_connection' is set
        if self.api_client.client_side_validation and ('update_connection' not in local_var_params or  # noqa: E501
                                                        local_var_params['update_connection'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `update_connection` when calling `update_connection`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'connection_id' in local_var_params:
            path_params['connection_id'] = local_var_params['connection_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_connection' in local_var_params:
            body_params = local_var_params['update_connection']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/connections/{connection_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ConnectionRespose',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))



# coding: utf-8

"""
    Kloudio APIs

"""


from __future__ import absolute_import

import unittest

import kloudio
from kloudio.api.connections_api import ConnectionsApi  # noqa: E501
from kloudio.rest import ApiException


class TestConnectionsApi(unittest.TestCase):
    """ConnectionsApi unit test stubs"""

    def setUp(self):
        self.api = kloudio.api.connections_api.ConnectionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_clone_connection(self):
        """Test case for clone_connection

        Clone a connection  # noqa: E501
        """
        pass

    def test_create_connection(self):
        """Test case for create_connection

        Create a connection  # noqa: E501
        """
        pass

    def test_delete_connection(self):
        """Test case for delete_connection

        Delete a connection  # noqa: E501
        """
        pass

    def test_retrieve_connection(self):
        """Test case for retrieve_connection

        Get a connection  # noqa: E501
        """
        pass

    def test_retrieve_connections(self):
        """Test case for retrieve_connections

        Get all connections  # noqa: E501
        """
        pass

    def test_share_connection(self):
        """Test case for share_connection

        Share a connection  # noqa: E501
        """
        pass

    def test_update_connection(self):
        """Test case for update_connection

        Update a connection  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kloudio APIs

"""


from __future__ import absolute_import

import unittest
import datetime

import kloudio
from kloudio.models.report_del_response import ReportDelResponse  # noqa: E501
from kloudio.rest import ApiException

class TestReportDelResponse(unittest.TestCase):
    """ReportDelResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ReportDelResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = kloudio.models.report_del_response.ReportDelResponse()  # noqa: E501
        if include_optional :
            return ReportDelResponse(
                object = 'report', 
                id = 'hwuhuwE&WYE12weA31', 
                deleted = True
            )
        else :
            return ReportDelResponse(
                object = 'report',
                id = 'hwuhuwE&WYE12weA31',
                deleted = True,
        )

    def testReportDelResponse(self):
        """Test ReportDelResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kloudio APIs

"""


from __future__ import absolute_import

import unittest
import datetime

import kloudio
from kloudio.models.new_connection import NewConnection  # noqa: E501
from kloudio.rest import ApiException

class TestNewConnection(unittest.TestCase):
    """NewConnection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test NewConnection
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = kloudio.models.new_connection.NewConnection()  # noqa: E501
        if include_optional :
            return NewConnection(
                name = 'demo-connection', 
                host = 'localhost', 
                port = '1234', 
                database = 'users', 
                username = 'admin', 
                password = 'password', 
                connection_type = 'DATABASE', 
                db_type = 'MYSQL', 
                production = True, 
                ssl = True, 
                share_with = [], 
                enable_tunnel = True, 
                tunnel_info = None, 
                other_options = None, 
                fed = True, 
                dw = True, 
                metadata = '0', 
                integration_user_id = 1.337, 
                web_type = '0', 
                ssl_info = None
            )
        else :
            return NewConnection(
                name = 'demo-connection',
                host = 'localhost',
                port = '1234',
                database = 'users',
                username = 'admin',
                password = 'password',
                connection_type = 'DATABASE',
                db_type = 'MYSQL',
        )

    def testNewConnection(self):
        """Test NewConnection"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kloudio APIs

"""


from __future__ import absolute_import

import unittest
import datetime

import kloudio
from kloudio.models.update_license import UpdateLicense  # noqa: E501
from kloudio.rest import ApiException

class TestUpdateLicense(unittest.TestCase):
    """UpdateLicense unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UpdateLicense
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = kloudio.models.update_license.UpdateLicense()  # noqa: E501
        if include_optional :
            return UpdateLicense(
                first_name = 'John', 
                id = 3995, 
                last_name = 'Doe', 
                role = 'creator | viewer | Admin | User'
            )
        else :
            return UpdateLicense(
                first_name = 'John',
                id = 3995,
                last_name = 'Doe',
                role = 'creator | viewer | Admin | User',
        )

    def testUpdateLicense(self):
        """Test UpdateLicense"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kloudio APIs

"""


from __future__ import absolute_import

import unittest
import datetime

import kloudio
from kloudio.models.reports_response import ReportsResponse  # noqa: E501
from kloudio.rest import ApiException

class TestReportsResponse(unittest.TestCase):
    """ReportsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ReportsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = kloudio.models.reports_response.ReportsResponse()  # noqa: E501
        if include_optional :
            return ReportsResponse(
                name = 'mysql-report', 
                id = 'LPdqQW-Kri0ZfU1a', 
                connection_id = 'LPdqQW-Kri0ZfU1a', 
                description = 'This is a sample query', 
                db_query = 'SELECT * FROM users;', 
                db_table = 'users', 
                sql_mode = True, 
                connection_type = 'DB', 
                _query_params = {}, 
                selected_cols = {}, 
                available_cols = {}, 
                shared_with = {}, 
                db_schema = '0', 
                tags = finance, money, 
                db_database = 'kloud', 
                joins = {}, 
                custom_join = '0', 
                additional_info = {}, 
                join_tables = {}, 
                settings = {}, 
                model = {}, 
                user_id = 87, 
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                query_version = 2, 
                db_type = 'CUSTOMAPI', 
                domain = 'test.com'
            )
        else :
            return ReportsResponse(
                name = 'mysql-report',
                id = 'LPdqQW-Kri0ZfU1a',
                connection_id = 'LPdqQW-Kri0ZfU1a',
        )

    def testReportsResponse(self):
        """Test ReportsResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kloudio APIs

"""


from __future__ import absolute_import

import unittest
import datetime

import kloudio
from kloudio.models.error_response import ErrorResponse  # noqa: E501
from kloudio.rest import ApiException

class TestErrorResponse(unittest.TestCase):
    """ErrorResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ErrorResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = kloudio.models.error_response.ErrorResponse()  # noqa: E501
        if include_optional :
            return ErrorResponse(
                id = 'XNfpjL4C9ZyCxo6j', 
                resource = 'connections | jobs | reports | templates | teams', 
                error = 'invalid_id | connection_already_exists', 
                message = 'The ID you have provided does not exist'
            )
        else :
            return ErrorResponse(
                error = 'invalid_id | connection_already_exists',
                message = 'The ID you have provided does not exist',
        )

    def testErrorResponse(self):
        """Test ErrorResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kloudio APIs

"""


from __future__ import absolute_import

import unittest
import datetime

import kloudio
from kloudio.models.new_job import NewJob  # noqa: E501
from kloudio.rest import ApiException

class TestNewJob(unittest.TestCase):
    """NewJob unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test NewJob
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = kloudio.models.new_job.NewJob()  # noqa: E501
        if include_optional :
            return NewJob(
                destination = 'email', 
                report_name = 'mysql-report', 
                report_id = '57d3273aed8c3e1e1c0d3746', 
                report_params = None, 
                frequency = 'Hourly', 
                am_pm = 'am', 
                hour = '01', 
                minute = '45', 
                day = 'Monday', 
                description = 'This is a sample query', 
                spreadsheet_id = '1-sl-_DtdBUmbi-FyJOwc2dXGd6xX0xZstX7UzlsU_EA', 
                sheet_id = '193832851', 
                sheet_name = 'Sales-v2', 
                timezone = 'PST', 
                select_cols = users, 
                tags = 'users', 
                email_on_success = True, 
                email_on_error = True, 
                metadata = None, 
                template_id = 'Y-z-jjFZ0H3u3maN', 
                template_name = 'Template2404a', 
                job_type = 'EMAIL'
            )
        else :
            return NewJob(
                destination = 'email',
                report_name = 'mysql-report',
                report_id = '57d3273aed8c3e1e1c0d3746',
                frequency = 'Hourly',
                am_pm = 'am',
                hour = '01',
                minute = '45',
                day = 'Monday',
        )

    def testNewJob(self):
        """Test NewJob"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kloudio APIs

"""


from __future__ import absolute_import

import unittest

import kloudio
from kloudio.api.reports_api import ReportsApi  # noqa: E501
from kloudio.rest import ApiException


class TestReportsApi(unittest.TestCase):
    """ReportsApi unit test stubs"""

    def setUp(self):
        self.api = kloudio.api.reports_api.ReportsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_report(self):
        """Test case for create_report

        Create a report  # noqa: E501
        """
        pass

    def test_delete_report(self):
        """Test case for delete_report

        Delete a report  # noqa: E501
        """
        pass

    def test_execute_report(self):
        """Test case for execute_report

        Execute a report  # noqa: E501
        """
        pass

    def test_get_report(self):
        """Test case for get_report

        Get a report  # noqa: E501
        """
        pass

    def test_get_reports(self):
        """Test case for get_reports

        Get all report  # noqa: E501
        """
        pass

    def test_share_report(self):
        """Test case for share_report

        Share a report  # noqa: E501
        """
        pass

    def test_update_report(self):
        """Test case for update_report

        Update a report  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kloudio APIs

"""


import pprint
import re  # noqa: F401

import six

from kloudio.configuration import Configuration


class ConnectionRespose(object):
    """
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'host': 'str',
        'port': 'str',
        'database': 'str',
        'username': 'str',
        'password': 'str',
        'db_type': 'str',
        'production': 'bool',
        'user': 'float',
        'updated_at': 'datetime',
        'ssl': 'bool',
        'updated_by': 'str',
        'created_at': 'datetime',
        'shared_with': 'object',
        'enable_tunnel': 'bool',
        'tunnel_info': 'object',
        'other_options': 'object',
        'fed': 'bool',
        'dw': 'bool',
        'metadata': 'str',
        'connection_type': 'str',
        'integration_user_id': 'float',
        'web_type': 'str',
        'ssl_info': 'object'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'host': 'host',
        'port': 'port',
        'database': 'database',
        'username': 'username',
        'password': 'password',
        'db_type': 'dbType',
        'production': 'production',
        'user': 'user',
        'updated_at': 'updatedAt',
        'ssl': 'ssl',
        'updated_by': 'updatedBy',
        'created_at': 'createdAt',
        'shared_with': 'sharedWith',
        'enable_tunnel': 'enableTunnel',
        'tunnel_info': 'tunnelInfo',
        'other_options': 'otherOptions',
        'fed': 'fed',
        'dw': 'dw',
        'metadata': 'metadata',
        'connection_type': 'connectionType',
        'integration_user_id': 'integrationUserId',
        'web_type': 'webType',
        'ssl_info': 'sslInfo'
    }

    def __init__(self, id=None, name=None, host=None, port=None, database=None, username=None, password=None, db_type=None, production=None, user=None, updated_at=None, ssl=None, updated_by=None, created_at=None, shared_with=None, enable_tunnel=None, tunnel_info=None, other_options=None, fed=None, dw=None, metadata=None, connection_type=None, integration_user_id=None, web_type=None, ssl_info=None, local_vars_configuration=None):  # noqa: E501
        """ConnectionRespose - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._host = None
        self._port = None
        self._database = None
        self._username = None
        self._password = None
        self._db_type = None
        self._production = None
        self._user = None
        self._updated_at = None
        self._ssl = None
        self._updated_by = None
        self._created_at = None
        self._shared_with = None
        self._enable_tunnel = None
        self._tunnel_info = None
        self._other_options = None
        self._fed = None
        self._dw = None
        self._metadata = None
        self._connection_type = None
        self._integration_user_id = None
        self._web_type = None
        self._ssl_info = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.host = host
        self.port = port
        self.database = database
        if username is not None:
            self.username = username
        if password is not None:
            self.password = password
        if db_type is not None:
            self.db_type = db_type
        if production is not None:
            self.production = production
        if user is not None:
            self.user = user
        if updated_at is not None:
            self.updated_at = updated_at
        if ssl is not None:
            self.ssl = ssl
        if updated_by is not None:
            self.updated_by = updated_by
        if created_at is not None:
            self.created_at = created_at
        if shared_with is not None:
            self.shared_with = shared_with
        if enable_tunnel is not None:
            self.enable_tunnel = enable_tunnel
        if tunnel_info is not None:
            self.tunnel_info = tunnel_info
        if other_options is not None:
            self.other_options = other_options
        if fed is not None:
            self.fed = fed
        if dw is not None:
            self.dw = dw
        if metadata is not None:
            self.metadata = metadata
        if connection_type is not None:
            self.connection_type = connection_type
        if integration_user_id is not None:
            self.integration_user_id = integration_user_id
        if web_type is not None:
            self.web_type = web_type
        if ssl_info is not None:
            self.ssl_info = ssl_info

    @property
    def id(self):
        """Gets the id of this ConnectionRespose.  # noqa: E501


        :return: The id of this ConnectionRespose.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ConnectionRespose.


        :param id: The id of this ConnectionRespose.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this ConnectionRespose.  # noqa: E501


        :return: The name of this ConnectionRespose.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ConnectionRespose.


        :param name: The name of this ConnectionRespose.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def host(self):
        """Gets the host of this ConnectionRespose.  # noqa: E501


        :return: The host of this ConnectionRespose.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this ConnectionRespose.


        :param host: The host of this ConnectionRespose.  # noqa: E501
        :type host: str
        """
        if self.local_vars_configuration.client_side_validation and host is None:  # noqa: E501
            raise ValueError("Invalid value for `host`, must not be `None`")  # noqa: E501

        self._host = host

    @property
    def port(self):
        """Gets the port of this ConnectionRespose.  # noqa: E501


        :return: The port of this ConnectionRespose.  # noqa: E501
        :rtype: str
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this ConnectionRespose.


        :param port: The port of this ConnectionRespose.  # noqa: E501
        :type port: str
        """
        if self.local_vars_configuration.client_side_validation and port is None:  # noqa: E501
            raise ValueError("Invalid value for `port`, must not be `None`")  # noqa: E501

        self._port = port

    @property
    def database(self):
        """Gets the database of this ConnectionRespose.  # noqa: E501


        :return: The database of this ConnectionRespose.  # noqa: E501
        :rtype: str
        """
        return self._database

    @database.setter
    def database(self, database):
        """Sets the database of this ConnectionRespose.


        :param database: The database of this ConnectionRespose.  # noqa: E501
        :type database: str
        """
        if self.local_vars_configuration.client_side_validation and database is None:  # noqa: E501
            raise ValueError("Invalid value for `database`, must not be `None`")  # noqa: E501

        self._database = database

    @property
    def username(self):
        """Gets the username of this ConnectionRespose.  # noqa: E501


        :return: The username of this ConnectionRespose.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this ConnectionRespose.


        :param username: The username of this ConnectionRespose.  # noqa: E501
        :type username: str
        """

        self._username = username

    @property
    def password(self):
        """Gets the password of this ConnectionRespose.  # noqa: E501


        :return: The password of this ConnectionRespose.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this ConnectionRespose.


        :param password: The password of this ConnectionRespose.  # noqa: E501
        :type password: str
        """

        self._password = password

    @property
    def db_type(self):
        """Gets the db_type of this ConnectionRespose.  # noqa: E501


        :return: The db_type of this ConnectionRespose.  # noqa: E501
        :rtype: str
        """
        return self._db_type

    @db_type.setter
    def db_type(self, db_type):
        """Sets the db_type of this ConnectionRespose.


        :param db_type: The db_type of this ConnectionRespose.  # noqa: E501
        :type db_type: str
        """

        self._db_type = db_type

    @property
    def production(self):
        """Gets the production of this ConnectionRespose.  # noqa: E501


        :return: The production of this ConnectionRespose.  # noqa: E501
        :rtype: bool
        """
        return self._production

    @production.setter
    def production(self, production):
        """Sets the production of this ConnectionRespose.


        :param production: The production of this ConnectionRespose.  # noqa: E501
        :type production: bool
        """

        self._production = production

    @property
    def user(self):
        """Gets the user of this ConnectionRespose.  # noqa: E501


        :return: The user of this ConnectionRespose.  # noqa: E501
        :rtype: float
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this ConnectionRespose.


        :param user: The user of this ConnectionRespose.  # noqa: E501
        :type user: float
        """

        self._user = user

    @property
    def updated_at(self):
        """Gets the updated_at of this ConnectionRespose.  # noqa: E501


        :return: The updated_at of this ConnectionRespose.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ConnectionRespose.


        :param updated_at: The updated_at of this ConnectionRespose.  # noqa: E501
        :type updated_at: datetime
        """

        self._updated_at = updated_at

    @property
    def ssl(self):
        """Gets the ssl of this ConnectionRespose.  # noqa: E501


        :return: The ssl of this ConnectionRespose.  # noqa: E501
        :rtype: bool
        """
        return self._ssl

    @ssl.setter
    def ssl(self, ssl):
        """Sets the ssl of this ConnectionRespose.


        :param ssl: The ssl of this ConnectionRespose.  # noqa: E501
        :type ssl: bool
        """

        self._ssl = ssl

    @property
    def updated_by(self):
        """Gets the updated_by of this ConnectionRespose.  # noqa: E501


        :return: The updated_by of this ConnectionRespose.  # noqa: E501
        :rtype: str
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """Sets the updated_by of this ConnectionRespose.


        :param updated_by: The updated_by of this ConnectionRespose.  # noqa: E501
        :type updated_by: str
        """

        self._updated_by = updated_by

    @property
    def created_at(self):
        """Gets the created_at of this ConnectionRespose.  # noqa: E501


        :return: The created_at of this ConnectionRespose.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ConnectionRespose.


        :param created_at: The created_at of this ConnectionRespose.  # noqa: E501
        :type created_at: datetime
        """

        self._created_at = created_at

    @property
    def shared_with(self):
        """Gets the shared_with of this ConnectionRespose.  # noqa: E501


        :return: The shared_with of this ConnectionRespose.  # noqa: E501
        :rtype: object
        """
        return self._shared_with

    @shared_with.setter
    def shared_with(self, shared_with):
        """Sets the shared_with of this ConnectionRespose.


        :param shared_with: The shared_with of this ConnectionRespose.  # noqa: E501
        :type shared_with: object
        """

        self._shared_with = shared_with

    @property
    def enable_tunnel(self):
        """Gets the enable_tunnel of this ConnectionRespose.  # noqa: E501


        :return: The enable_tunnel of this ConnectionRespose.  # noqa: E501
        :rtype: bool
        """
        return self._enable_tunnel

    @enable_tunnel.setter
    def enable_tunnel(self, enable_tunnel):
        """Sets the enable_tunnel of this ConnectionRespose.


        :param enable_tunnel: The enable_tunnel of this ConnectionRespose.  # noqa: E501
        :type enable_tunnel: bool
        """

        self._enable_tunnel = enable_tunnel

    @property
    def tunnel_info(self):
        """Gets the tunnel_info of this ConnectionRespose.  # noqa: E501


        :return: The tunnel_info of this ConnectionRespose.  # noqa: E501
        :rtype: object
        """
        return self._tunnel_info

    @tunnel_info.setter
    def tunnel_info(self, tunnel_info):
        """Sets the tunnel_info of this ConnectionRespose.


        :param tunnel_info: The tunnel_info of this ConnectionRespose.  # noqa: E501
        :type tunnel_info: object
        """

        self._tunnel_info = tunnel_info

    @property
    def other_options(self):
        """Gets the other_options of this ConnectionRespose.  # noqa: E501


        :return: The other_options of this ConnectionRespose.  # noqa: E501
        :rtype: object
        """
        return self._other_options

    @other_options.setter
    def other_options(self, other_options):
        """Sets the other_options of this ConnectionRespose.


        :param other_options: The other_options of this ConnectionRespose.  # noqa: E501
        :type other_options: object
        """

        self._other_options = other_options

    @property
    def fed(self):
        """Gets the fed of this ConnectionRespose.  # noqa: E501


        :return: The fed of this ConnectionRespose.  # noqa: E501
        :rtype: bool
        """
        return self._fed

    @fed.setter
    def fed(self, fed):
        """Sets the fed of this ConnectionRespose.


        :param fed: The fed of this ConnectionRespose.  # noqa: E501
        :type fed: bool
        """

        self._fed = fed

    @property
    def dw(self):
        """Gets the dw of this ConnectionRespose.  # noqa: E501


        :return: The dw of this ConnectionRespose.  # noqa: E501
        :rtype: bool
        """
        return self._dw

    @dw.setter
    def dw(self, dw):
        """Sets the dw of this ConnectionRespose.


        :param dw: The dw of this ConnectionRespose.  # noqa: E501
        :type dw: bool
        """

        self._dw = dw

    @property
    def metadata(self):
        """Gets the metadata of this ConnectionRespose.  # noqa: E501


        :return: The metadata of this ConnectionRespose.  # noqa: E501
        :rtype: str
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this ConnectionRespose.


        :param metadata: The metadata of this ConnectionRespose.  # noqa: E501
        :type metadata: str
        """

        self._metadata = metadata

    @property
    def connection_type(self):
        """Gets the connection_type of this ConnectionRespose.  # noqa: E501


        :return: The connection_type of this ConnectionRespose.  # noqa: E501
        :rtype: str
        """
        return self._connection_type

    @connection_type.setter
    def connection_type(self, connection_type):
        """Sets the connection_type of this ConnectionRespose.


        :param connection_type: The connection_type of this ConnectionRespose.  # noqa: E501
        :type connection_type: str
        """

        self._connection_type = connection_type

    @property
    def integration_user_id(self):
        """Gets the integration_user_id of this ConnectionRespose.  # noqa: E501


        :return: The integration_user_id of this ConnectionRespose.  # noqa: E501
        :rtype: float
        """
        return self._integration_user_id

    @integration_user_id.setter
    def integration_user_id(self, integration_user_id):
        """Sets the integration_user_id of this ConnectionRespose.


        :param integration_user_id: The integration_user_id of this ConnectionRespose.  # noqa: E501
        :type integration_user_id: float
        """

        self._integration_user_id = integration_user_id

    @property
    def web_type(self):
        """Gets the web_type of this ConnectionRespose.  # noqa: E501


        :return: The web_type of this ConnectionRespose.  # noqa: E501
        :rtype: str
        """
        return self._web_type

    @web_type.setter
    def web_type(self, web_type):
        """Sets the web_type of this ConnectionRespose.


        :param web_type: The web_type of this ConnectionRespose.  # noqa: E501
        :type web_type: str
        """

        self._web_type = web_type

    @property
    def ssl_info(self):
        """Gets the ssl_info of this ConnectionRespose.  # noqa: E501


        :return: The ssl_info of this ConnectionRespose.  # noqa: E501
        :rtype: object
        """
        return self._ssl_info

    @ssl_info.setter
    def ssl_info(self, ssl_info):
        """Sets the ssl_info of this ConnectionRespose.


        :param ssl_info: The ssl_info of this ConnectionRespose.  # noqa: E501
        :type ssl_info: object
        """

        self._ssl_info = ssl_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConnectionRespose):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConnectionRespose):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kloudio APIs

"""


from __future__ import absolute_import

import unittest

import kloudio
from kloudio.api.license_api import LicenseApi  # noqa: E501
from kloudio.rest import ApiException


class TestLicenseApi(unittest.TestCase):
    """LicenseApi unit test stubs"""

    def setUp(self):
        self.api = kloudio.api.license_api.LicenseApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_license(self):
        """Test case for create_license

        Create a license  # noqa: E501
        """
        pass

    def test_delete_license(self):
        """Test case for delete_license

        Delete a license  # noqa: E501
        """
        pass

    def test_get_licenses(self):
        """Test case for get_licenses

        Get all licenses  # noqa: E501
        """
        pass

    def test_update_license(self):
        """Test case for update_license

        Update a license  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Kloudio APIs

"""


import pprint
import re  # noqa: F401

import six

from kloudio.configuration import Configuration


class UpdateConnection(object):
    """
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'host': 'str',
        'port': 'str',
        'database': 'str',
        'username': 'str',
        'password': 'str',
        'production': 'bool',
        'ssl': 'bool',
        'enable_tunnel': 'bool',
        'tunnel_info': 'object',
        'ssl_info': 'object'
    }

    attribute_map = {
        'name': 'name',
        'host': 'host',
        'port': 'port',
        'database': 'database',
        'username': 'username',
        'password': 'password',
        'production': 'production',
        'ssl': 'ssl',
        'enable_tunnel': 'enableTunnel',
        'tunnel_info': 'tunnelInfo',
        'ssl_info': 'sslInfo'
    }

    def __init__(self, name=None, host=None, port=None, database=None, username=None, password=None, production=None, ssl=None, enable_tunnel=None, tunnel_info=None, ssl_info=None, local_vars_configuration=None):  # noqa: E501
        """UpdateConnection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._host = None
        self._port = None
        self._database = None
        self._username = None
        self._password = None
        self._production = None
        self._ssl = None
        self._enable_tunnel = None
        self._tunnel_info = None
        self._ssl_info = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if host is not None:
            self.host = host
        if port is not None:
            self.port = port
        if database is not None:
            self.database = database
        if username is not None:
            self.username = username
        if password is not None:
            self.password = password
        if production is not None:
            self.production = production
        if ssl is not None:
            self.ssl = ssl
        if enable_tunnel is not None:
            self.enable_tunnel = enable_tunnel
        if tunnel_info is not None:
            self.tunnel_info = tunnel_info
        if ssl_info is not None:
            self.ssl_info = ssl_info

    @property
    def name(self):
        """Gets the name of this UpdateConnection.  # noqa: E501


        :return: The name of this UpdateConnection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this UpdateConnection.


        :param name: The name of this UpdateConnection.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def host(self):
        """Gets the host of this UpdateConnection.  # noqa: E501


        :return: The host of this UpdateConnection.  # noqa: E501
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """Sets the host of this UpdateConnection.


        :param host: The host of this UpdateConnection.  # noqa: E501
        :type host: str
        """

        self._host = host

    @property
    def port(self):
        """Gets the port of this UpdateConnection.  # noqa: E501


        :return: The port of this UpdateConnection.  # noqa: E501
        :rtype: str
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this UpdateConnection.


        :param port: The port of this UpdateConnection.  # noqa: E501
        :type port: str
        """

        self._port = port

    @property
    def database(self):
        """Gets the database of this UpdateConnection.  # noqa: E501


        :return: The database of this UpdateConnection.  # noqa: E501
        :rtype: str
        """
        return self._database

    @database.setter
    def database(self, database):
        """Sets the database of this UpdateConnection.


        :param database: The database of this UpdateConnection.  # noqa: E501
        :type database: str
        """

        self._database = database

    @property
    def username(self):
        """Gets the username of this UpdateConnection.  # noqa: E501


        :return: The username of this UpdateConnection.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this UpdateConnection.


        :param username: The username of this UpdateConnection.  # noqa: E501
        :type username: str
        """

        self._username = username

    @property
    def password(self):
        """Gets the password of this UpdateConnection.  # noqa: E501


        :return: The password of this UpdateConnection.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this UpdateConnection.


        :param password: The password of this UpdateConnection.  # noqa: E501
        :type password: str
        """

        self._password = password

    @property
    def production(self):
        """Gets the production of this UpdateConnection.  # noqa: E501


        :return: The production of this UpdateConnection.  # noqa: E501
        :rtype: bool
        """
        return self._production

    @production.setter
    def production(self, production):
        """Sets the production of this UpdateConnection.


        :param production: The production of this UpdateConnection.  # noqa: E501
        :type production: bool
        """

        self._production = production

    @property
    def ssl(self):
        """Gets the ssl of this UpdateConnection.  # noqa: E501


        :return: The ssl of this UpdateConnection.  # noqa: E501
        :rtype: bool
        """
        return self._ssl

    @ssl.setter
    def ssl(self, ssl):
        """Sets the ssl of this UpdateConnection.


        :param ssl: The ssl of this UpdateConnection.  # noqa: E501
        :type ssl: bool
        """

        self._ssl = ssl

    @property
    def enable_tunnel(self):
        """Gets the enable_tunnel of this UpdateConnection.  # noqa: E501


        :return: The enable_tunnel of this UpdateConnection.  # noqa: E501
        :rtype: bool
        """
        return self._enable_tunnel

    @enable_tunnel.setter
    def enable_tunnel(self, enable_tunnel):
        """Sets the enable_tunnel of this UpdateConnection.


        :param enable_tunnel: The enable_tunnel of this UpdateConnection.  # noqa: E501
        :type enable_tunnel: bool
        """

        self._enable_tunnel = enable_tunnel

    @property
    def tunnel_info(self):
        """Gets the tunnel_info of this UpdateConnection.  # noqa: E501


        :return: The tunnel_info of this UpdateConnection.  # noqa: E501
        :rtype: object
        """
        return self._tunnel_info

    @tunnel_info.setter
    def tunnel_info(self, tunnel_info):
        """Sets the tunnel_info of this UpdateConnection.


        :param tunnel_info: The tunnel_info of this UpdateConnection.  # noqa: E501
        :type tunnel_info: object
        """

        self._tunnel_info = tunnel_info

    @property
    def ssl_info(self):
        """Gets the ssl_info of this UpdateConnection.  # noqa: E501


        :return: The ssl_info of this UpdateConnection.  # noqa: E501
        :rtype: object
        """
        return self._ssl_info

    @ssl_info.setter
    def ssl_info(self, ssl_info):
        """Sets the ssl_info of this UpdateConnection.


        :param ssl_info: The ssl_info of this UpdateConnection.  # noqa: E501
        :type ssl_info: object
        """

        self._ssl_info = ssl_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateConnection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateConnection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Kloudio APIs

"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from kloudio.api.connections_api import ConnectionsApi
from kloudio.api.jobs_api import JobsApi
from kloudio.api.license_api import LicenseApi
from kloudio.api.register_api import RegisterApi
from kloudio.api.reports_api import ReportsApi

# import ApiClient
from kloudio.api_client import ApiClient
from kloudio.configuration import Configuration
from kloudio.exceptions import OpenApiException
from kloudio.exceptions import ApiTypeError
from kloudio.exceptions import ApiValueError
from kloudio.exceptions import ApiKeyError
from kloudio.exceptions import ApiAttributeError
from kloudio.exceptions import ApiException
# import models into sdk package
from kloudio.models.connection_del_response import ConnectionDelResponse
from kloudio.models.connection_respose import ConnectionRespose
from kloudio.models.connection_share_response import ConnectionShareResponse
from kloudio.models.error_response import ErrorResponse
from kloudio.models.jobs_array import JobsArray
from kloudio.models.new_connection import NewConnection
from kloudio.models.new_job import NewJob
from kloudio.models.new_license import NewLicense
from kloudio.models.new_report import NewReport
from kloudio.models.new_user import NewUser
from kloudio.models.report_del_response import ReportDelResponse
from kloudio.models.report_share_response import ReportShareResponse
from kloudio.models.reports_response import ReportsResponse
from kloudio.models.run_report import RunReport
from kloudio.models.share_connection import ShareConnection
from kloudio.models.share_report import ShareReport
from kloudio.models.update_connection import UpdateConnection
from kloudio.models.update_license import UpdateLicense




# coding: utf-8

"""
    Kloudio APIs

"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "Kloudio"
VERSION = "1.0.0"
AUTHOR = "Kloudio"
AUTHOR_EMAIL = "developer@kloud.io"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    description="Kloudio APIs",
    author=AUTHOR,
    author_email= AUTHOR_EMAIL,
    url="https://github.com/Kloudio/sdk-python",
    keywords=["SDK", "API", "Kloudio APIs"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description_content_type="text/markdown",
    long_description="""\
    # Kloudio Python Library

- API version: BETA
- Package version: 1.0.0

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

```sh
pip install kloudio
```
(you may need to run `pip` with root permission: `sudo pip install kloudio`)

Then import the package:
```python
import kloudio
```

## Using Kloudio API

Documentation for the Python library can be found at https://github.com/Kloudio/sdk-python



    """
)



# coding: utf-8

"""
    Kloudio APIs

"""


import pprint
import re  # noqa: F401

import six

from kloudio.configuration import Configuration


class RunReport(object):
    """
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        '_query_params': 'object',
        'preview_rows': 'float'
    }

    attribute_map = {
        '_query_params': 'queryParams',
        'preview_rows': 'previewRows'
    }

    def __init__(self, _query_params=None, preview_rows=None, local_vars_configuration=None):  # noqa: E501
        """RunReport - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self.__query_params = None
        self._preview_rows = None
        self.discriminator = None

        if _query_params is not None:
            self._query_params = _query_params
        if preview_rows is not None:
            self.preview_rows = preview_rows

    @property
    def _query_params(self):
        """Gets the _query_params of this RunReport.  # noqa: E501


        :return: The _query_params of this RunReport.  # noqa: E501
        :rtype: object
        """
        return self.__query_params

    @_query_params.setter
    def _query_params(self, _query_params):
        """Sets the _query_params of this RunReport.


        :param _query_params: The _query_params of this RunReport.  # noqa: E501
        :type _query_params: object
        """

        self.__query_params = _query_params

    @property
    def preview_rows(self):
        """Gets the preview_rows of this RunReport.  # noqa: E501


        :return: The preview_rows of this RunReport.  # noqa: E501
        :rtype: float
        """
        return self._preview_rows

    @preview_rows.setter
    def preview_rows(self, preview_rows):
        """Sets the preview_rows of this RunReport.


        :param preview_rows: The preview_rows of this RunReport.  # noqa: E501
        :type preview_rows: float
        """

        self._preview_rows = preview_rows

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunReport):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RunReport):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Kloudio APIs

"""


import pprint
import re  # noqa: F401

import six

from kloudio.configuration import Configuration


class ReportsResponse(object):
    """
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'id': 'str',
        'connection_id': 'str',
        'description': 'str',
        'db_query': 'str',
        'db_table': 'str',
        'sql_mode': 'bool',
        'connection_type': 'str',
        '_query_params': 'object',
        'selected_cols': 'object',
        'available_cols': 'object',
        'shared_with': 'object',
        'db_schema': 'str',
        'tags': 'list[str]',
        'db_database': 'str',
        'joins': 'object',
        'custom_join': 'str',
        'additional_info': 'object',
        'join_tables': 'object',
        'settings': 'object',
        'model': 'object',
        'user_id': 'float',
        'updated_at': 'datetime',
        'created_at': 'datetime',
        'query_version': 'float',
        'db_type': 'str',
        'domain': 'str'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'connection_id': 'connectionId',
        'description': 'description',
        'db_query': 'dbQuery',
        'db_table': 'dbTable',
        'sql_mode': 'sqlMode',
        'connection_type': 'connectionType',
        '_query_params': 'queryParams',
        'selected_cols': 'selectedCols',
        'available_cols': 'availableCols',
        'shared_with': 'sharedWith',
        'db_schema': 'dbSchema',
        'tags': 'tags',
        'db_database': 'dbDatabase',
        'joins': 'joins',
        'custom_join': 'customJoin',
        'additional_info': 'additionalInfo',
        'join_tables': 'joinTables',
        'settings': 'settings',
        'model': 'model',
        'user_id': 'userId',
        'updated_at': 'updatedAt',
        'created_at': 'createdAt',
        'query_version': 'queryVersion',
        'db_type': 'dbType',
        'domain': 'domain'
    }

    def __init__(self, name=None, id=None, connection_id=None, description=None, db_query=None, db_table=None, sql_mode=None, connection_type=None, _query_params=None, selected_cols=None, available_cols=None, shared_with=None, db_schema=None, tags=None, db_database=None, joins=None, custom_join=None, additional_info=None, join_tables=None, settings=None, model=None, user_id=None, updated_at=None, created_at=None, query_version=None, db_type=None, domain=None, local_vars_configuration=None):  # noqa: E501
        """ReportsResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._id = None
        self._connection_id = None
        self._description = None
        self._db_query = None
        self._db_table = None
        self._sql_mode = None
        self._connection_type = None
        self.__query_params = None
        self._selected_cols = None
        self._available_cols = None
        self._shared_with = None
        self._db_schema = None
        self._tags = None
        self._db_database = None
        self._joins = None
        self._custom_join = None
        self._additional_info = None
        self._join_tables = None
        self._settings = None
        self._model = None
        self._user_id = None
        self._updated_at = None
        self._created_at = None
        self._query_version = None
        self._db_type = None
        self._domain = None
        self.discriminator = None

        self.name = name
        self.id = id
        self.connection_id = connection_id
        if description is not None:
            self.description = description
        if db_query is not None:
            self.db_query = db_query
        if db_table is not None:
            self.db_table = db_table
        if sql_mode is not None:
            self.sql_mode = sql_mode
        if connection_type is not None:
            self.connection_type = connection_type
        if _query_params is not None:
            self._query_params = _query_params
        if selected_cols is not None:
            self.selected_cols = selected_cols
        if available_cols is not None:
            self.available_cols = available_cols
        if shared_with is not None:
            self.shared_with = shared_with
        if db_schema is not None:
            self.db_schema = db_schema
        if tags is not None:
            self.tags = tags
        if db_database is not None:
            self.db_database = db_database
        if joins is not None:
            self.joins = joins
        if custom_join is not None:
            self.custom_join = custom_join
        if additional_info is not None:
            self.additional_info = additional_info
        if join_tables is not None:
            self.join_tables = join_tables
        if settings is not None:
            self.settings = settings
        if model is not None:
            self.model = model
        if user_id is not None:
            self.user_id = user_id
        if updated_at is not None:
            self.updated_at = updated_at
        if created_at is not None:
            self.created_at = created_at
        if query_version is not None:
            self.query_version = query_version
        if db_type is not None:
            self.db_type = db_type
        if domain is not None:
            self.domain = domain

    @property
    def name(self):
        """Gets the name of this ReportsResponse.  # noqa: E501


        :return: The name of this ReportsResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ReportsResponse.


        :param name: The name of this ReportsResponse.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def id(self):
        """Gets the id of this ReportsResponse.  # noqa: E501


        :return: The id of this ReportsResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ReportsResponse.


        :param id: The id of this ReportsResponse.  # noqa: E501
        :type id: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def connection_id(self):
        """Gets the connection_id of this ReportsResponse.  # noqa: E501


        :return: The connection_id of this ReportsResponse.  # noqa: E501
        :rtype: str
        """
        return self._connection_id

    @connection_id.setter
    def connection_id(self, connection_id):
        """Sets the connection_id of this ReportsResponse.


        :param connection_id: The connection_id of this ReportsResponse.  # noqa: E501
        :type connection_id: str
        """
        if self.local_vars_configuration.client_side_validation and connection_id is None:  # noqa: E501
            raise ValueError("Invalid value for `connection_id`, must not be `None`")  # noqa: E501

        self._connection_id = connection_id

    @property
    def description(self):
        """Gets the description of this ReportsResponse.  # noqa: E501


        :return: The description of this ReportsResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ReportsResponse.


        :param description: The description of this ReportsResponse.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def db_query(self):
        """Gets the db_query of this ReportsResponse.  # noqa: E501


        :return: The db_query of this ReportsResponse.  # noqa: E501
        :rtype: str
        """
        return self._db_query

    @db_query.setter
    def db_query(self, db_query):
        """Sets the db_query of this ReportsResponse.


        :param db_query: The db_query of this ReportsResponse.  # noqa: E501
        :type db_query: str
        """

        self._db_query = db_query

    @property
    def db_table(self):
        """Gets the db_table of this ReportsResponse.  # noqa: E501


        :return: The db_table of this ReportsResponse.  # noqa: E501
        :rtype: str
        """
        return self._db_table

    @db_table.setter
    def db_table(self, db_table):
        """Sets the db_table of this ReportsResponse.


        :param db_table: The db_table of this ReportsResponse.  # noqa: E501
        :type db_table: str
        """

        self._db_table = db_table

    @property
    def sql_mode(self):
        """Gets the sql_mode of this ReportsResponse.  # noqa: E501


        :return: The sql_mode of this ReportsResponse.  # noqa: E501
        :rtype: bool
        """
        return self._sql_mode

    @sql_mode.setter
    def sql_mode(self, sql_mode):
        """Sets the sql_mode of this ReportsResponse.


        :param sql_mode: The sql_mode of this ReportsResponse.  # noqa: E501
        :type sql_mode: bool
        """

        self._sql_mode = sql_mode

    @property
    def connection_type(self):
        """Gets the connection_type of this ReportsResponse.  # noqa: E501


        :return: The connection_type of this ReportsResponse.  # noqa: E501
        :rtype: str
        """
        return self._connection_type

    @connection_type.setter
    def connection_type(self, connection_type):
        """Sets the connection_type of this ReportsResponse.


        :param connection_type: The connection_type of this ReportsResponse.  # noqa: E501
        :type connection_type: str
        """

        self._connection_type = connection_type

    @property
    def _query_params(self):
        """Gets the _query_params of this ReportsResponse.  # noqa: E501


        :return: The _query_params of this ReportsResponse.  # noqa: E501
        :rtype: object
        """
        return self.__query_params

    @_query_params.setter
    def _query_params(self, _query_params):
        """Sets the _query_params of this ReportsResponse.


        :param _query_params: The _query_params of this ReportsResponse.  # noqa: E501
        :type _query_params: object
        """

        self.__query_params = _query_params

    @property
    def selected_cols(self):
        """Gets the selected_cols of this ReportsResponse.  # noqa: E501


        :return: The selected_cols of this ReportsResponse.  # noqa: E501
        :rtype: object
        """
        return self._selected_cols

    @selected_cols.setter
    def selected_cols(self, selected_cols):
        """Sets the selected_cols of this ReportsResponse.


        :param selected_cols: The selected_cols of this ReportsResponse.  # noqa: E501
        :type selected_cols: object
        """

        self._selected_cols = selected_cols

    @property
    def available_cols(self):
        """Gets the available_cols of this ReportsResponse.  # noqa: E501


        :return: The available_cols of this ReportsResponse.  # noqa: E501
        :rtype: object
        """
        return self._available_cols

    @available_cols.setter
    def available_cols(self, available_cols):
        """Sets the available_cols of this ReportsResponse.


        :param available_cols: The available_cols of this ReportsResponse.  # noqa: E501
        :type available_cols: object
        """

        self._available_cols = available_cols

    @property
    def shared_with(self):
        """Gets the shared_with of this ReportsResponse.  # noqa: E501


        :return: The shared_with of this ReportsResponse.  # noqa: E501
        :rtype: object
        """
        return self._shared_with

    @shared_with.setter
    def shared_with(self, shared_with):
        """Sets the shared_with of this ReportsResponse.


        :param shared_with: The shared_with of this ReportsResponse.  # noqa: E501
        :type shared_with: object
        """

        self._shared_with = shared_with

    @property
    def db_schema(self):
        """Gets the db_schema of this ReportsResponse.  # noqa: E501


        :return: The db_schema of this ReportsResponse.  # noqa: E501
        :rtype: str
        """
        return self._db_schema

    @db_schema.setter
    def db_schema(self, db_schema):
        """Sets the db_schema of this ReportsResponse.


        :param db_schema: The db_schema of this ReportsResponse.  # noqa: E501
        :type db_schema: str
        """

        self._db_schema = db_schema

    @property
    def tags(self):
        """Gets the tags of this ReportsResponse.  # noqa: E501


        :return: The tags of this ReportsResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this ReportsResponse.


        :param tags: The tags of this ReportsResponse.  # noqa: E501
        :type tags: list[str]
        """

        self._tags = tags

    @property
    def db_database(self):
        """Gets the db_database of this ReportsResponse.  # noqa: E501


        :return: The db_database of this ReportsResponse.  # noqa: E501
        :rtype: str
        """
        return self._db_database

    @db_database.setter
    def db_database(self, db_database):
        """Sets the db_database of this ReportsResponse.


        :param db_database: The db_database of this ReportsResponse.  # noqa: E501
        :type db_database: str
        """

        self._db_database = db_database

    @property
    def joins(self):
        """Gets the joins of this ReportsResponse.  # noqa: E501


        :return: The joins of this ReportsResponse.  # noqa: E501
        :rtype: object
        """
        return self._joins

    @joins.setter
    def joins(self, joins):
        """Sets the joins of this ReportsResponse.


        :param joins: The joins of this ReportsResponse.  # noqa: E501
        :type joins: object
        """

        self._joins = joins

    @property
    def custom_join(self):
        """Gets the custom_join of this ReportsResponse.  # noqa: E501


        :return: The custom_join of this ReportsResponse.  # noqa: E501
        :rtype: str
        """
        return self._custom_join

    @custom_join.setter
    def custom_join(self, custom_join):
        """Sets the custom_join of this ReportsResponse.


        :param custom_join: The custom_join of this ReportsResponse.  # noqa: E501
        :type custom_join: str
        """

        self._custom_join = custom_join

    @property
    def additional_info(self):
        """Gets the additional_info of this ReportsResponse.  # noqa: E501


        :return: The additional_info of this ReportsResponse.  # noqa: E501
        :rtype: object
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info):
        """Sets the additional_info of this ReportsResponse.


        :param additional_info: The additional_info of this ReportsResponse.  # noqa: E501
        :type additional_info: object
        """

        self._additional_info = additional_info

    @property
    def join_tables(self):
        """Gets the join_tables of this ReportsResponse.  # noqa: E501


        :return: The join_tables of this ReportsResponse.  # noqa: E501
        :rtype: object
        """
        return self._join_tables

    @join_tables.setter
    def join_tables(self, join_tables):
        """Sets the join_tables of this ReportsResponse.


        :param join_tables: The join_tables of this ReportsResponse.  # noqa: E501
        :type join_tables: object
        """

        self._join_tables = join_tables

    @property
    def settings(self):
        """Gets the settings of this ReportsResponse.  # noqa: E501


        :return: The settings of this ReportsResponse.  # noqa: E501
        :rtype: object
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """Sets the settings of this ReportsResponse.


        :param settings: The settings of this ReportsResponse.  # noqa: E501
        :type settings: object
        """

        self._settings = settings

    @property
    def model(self):
        """Gets the model of this ReportsResponse.  # noqa: E501


        :return: The model of this ReportsResponse.  # noqa: E501
        :rtype: object
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this ReportsResponse.


        :param model: The model of this ReportsResponse.  # noqa: E501
        :type model: object
        """

        self._model = model

    @property
    def user_id(self):
        """Gets the user_id of this ReportsResponse.  # noqa: E501


        :return: The user_id of this ReportsResponse.  # noqa: E501
        :rtype: float
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this ReportsResponse.


        :param user_id: The user_id of this ReportsResponse.  # noqa: E501
        :type user_id: float
        """

        self._user_id = user_id

    @property
    def updated_at(self):
        """Gets the updated_at of this ReportsResponse.  # noqa: E501


        :return: The updated_at of this ReportsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this ReportsResponse.


        :param updated_at: The updated_at of this ReportsResponse.  # noqa: E501
        :type updated_at: datetime
        """

        self._updated_at = updated_at

    @property
    def created_at(self):
        """Gets the created_at of this ReportsResponse.  # noqa: E501


        :return: The created_at of this ReportsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this ReportsResponse.


        :param created_at: The created_at of this ReportsResponse.  # noqa: E501
        :type created_at: datetime
        """

        self._created_at = created_at

    @property
    def query_version(self):
        """Gets the query_version of this ReportsResponse.  # noqa: E501


        :return: The query_version of this ReportsResponse.  # noqa: E501
        :rtype: float
        """
        return self._query_version

    @query_version.setter
    def query_version(self, query_version):
        """Sets the query_version of this ReportsResponse.


        :param query_version: The query_version of this ReportsResponse.  # noqa: E501
        :type query_version: float
        """

        self._query_version = query_version

    @property
    def db_type(self):
        """Gets the db_type of this ReportsResponse.  # noqa: E501


        :return: The db_type of this ReportsResponse.  # noqa: E501
        :rtype: str
        """
        return self._db_type

    @db_type.setter
    def db_type(self, db_type):
        """Sets the db_type of this ReportsResponse.


        :param db_type: The db_type of this ReportsResponse.  # noqa: E501
        :type db_type: str
        """

        self._db_type = db_type

    @property
    def domain(self):
        """Gets the domain of this ReportsResponse.  # noqa: E501


        :return: The domain of this ReportsResponse.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this ReportsResponse.


        :param domain: The domain of this ReportsResponse.  # noqa: E501
        :type domain: str
        """

        self._domain = domain

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReportsResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ReportsResponse):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from kloudio.api.connections_api import ConnectionsApi
from kloudio.api.jobs_api import JobsApi
from kloudio.api.license_api import LicenseApi
from kloudio.api.register_api import RegisterApi
from kloudio.api.reports_api import ReportsApi



# coding: utf-8

"""
    Kloudio APIs

"""


from __future__ import absolute_import

import unittest
import datetime

import kloudio
from kloudio.models.connection_share_response import ConnectionShareResponse  # noqa: E501
from kloudio.rest import ApiException

class TestConnectionShareResponse(unittest.TestCase):
    """ConnectionShareResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ConnectionShareResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = kloudio.models.connection_share_response.ConnectionShareResponse()  # noqa: E501
        if include_optional :
            return ConnectionShareResponse(
                id = 'asd5AGWq-a@3', 
                object = 'connection', 
                shared_with = [{"id":87,"email":"satish@kloud.io","access":"Can Edit","inviterEmail":"lgkd333@kloud.io"}]
            )
        else :
            return ConnectionShareResponse(
                id = 'asd5AGWq-a@3',
                object = 'connection',
                shared_with = [{"id":87,"email":"satish@kloud.io","access":"Can Edit","inviterEmail":"lgkd333@kloud.io"}],
        )

    def testConnectionShareResponse(self):
        """Test ConnectionShareResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
